@@ -3,13 +3,16 @@
 from abc import ABC
 from dataclasses import dataclass, field
 from enum import Enum
+from functools import cached_property
+from pathlib import Path
 from typing import IO, Any, Dict, Iterable, List, Optional, Tuple, Union, cast
 
 from dataclasses_json import dataclass_json
 from yaml import safe_load
 
-from .expression import Sentence, TextChunk
-from .parse import parse_sentences
+from .expression import Expression, Sentence, TextChunk
+from .parse import parse_sentence, parse_sentences
+from .util import is_template, merge_dict, normalize_text
 
 
 class ResponseType(str, Enum):
@@ -22,11 +25,11 @@ class ResponseType(str, Enum):
     HANDLE_ERROR = "handle_error"
 
 
-@dataclass
+@dataclass(frozen=True)
 class IntentData:
     """Block of sentences and known slots for an intent."""
 
-    sentences: List[Sentence]
+    sentence_texts: List[str]
     """Sentence templates that match this intent."""
 
     slots: Dict[str, Any] = field(default_factory=dict)
@@ -38,6 +41,11 @@ class IntentData:
     excludes_context: Optional[Dict[str, Any]] = None
     """Context items that must not be present for match to be successful."""
 
+    @cached_property
+    def sentences(self) -> List[Sentence]:
+        """Sentence templates that match this intent."""
+        return parse_sentences(self.sentence_texts, keep_text=True)
+
 
 @dataclass_json
 @dataclass
@@ -80,7 +88,7 @@ class RangeSlotList(SlotList):
 class TextSlotValue:
     """Single value in a text slot list."""
 
-    text_in: TextChunk
+    text_in: Expression
     """Input text for this value"""
 
     value_out: Any
@@ -100,7 +108,7 @@ class TextSlotValue:
             context = cast(Tuple[str, Any, Dict[str, Any]], value_tuple)[2]
 
         return TextSlotValue(
-            text_in=TextChunk(text_in),
+            text_in=_maybe_parse_template(text_in),
             value_out=value_out,
             context=context,
         )
@@ -121,7 +129,7 @@ class TextSlotList(SlotList):
         """
         return TextSlotList(
             values=[
-                TextSlotValue(text_in=TextChunk(text), value_out=text)
+                TextSlotValue(text_in=_maybe_parse_template(text), value_out=text)
                 for text in strings
             ],
         )
@@ -159,6 +167,16 @@ class Intents:
     skip_words: List[str] = field(default_factory=list)
     """Words that can be skipped during recognition."""
 
+    @staticmethod
+    def from_files(file_paths: Iterable[Union[str, Path]]) -> "Intents":
+        """Load intents from YAML file paths."""
+        intents_dict: Dict[str, Any] = {}
+        for file_path in file_paths:
+            with open(file_path, "r", encoding="utf-8") as yaml_file:
+                merge_dict(intents_dict, safe_load(yaml_file))
+
+        return Intents.from_dict(intents_dict)
+
     @staticmethod
     def from_yaml(yaml_file: IO[str]) -> "Intents":
         """Load intents from a YAML file."""
@@ -191,9 +209,7 @@ class Intents:
                     name=intent_name,
                     data=[
                         IntentData(
-                            sentences=parse_sentences(
-                                data_dict["sentences"], keep_text=True
-                            ),
+                            sentence_texts=data_dict["sentences"],
                             slots=data_dict.get("slots", {}),
                             requires_context=data_dict.get("requires_context"),
                             excludes_context=data_dict.get("excludes_context"),
@@ -226,13 +242,13 @@ def _parse_list(list_dict: Dict[str, Any]) -> SlotList:
             if isinstance(value, str):
                 # String value
                 text_values.append(
-                    TextSlotValue(text_in=TextChunk(value), value_out=value)
+                    TextSlotValue(text_in=_maybe_parse_template(value), value_out=value)
                 )
             else:
                 # Object with "in" and "out"
                 text_values.append(
                     TextSlotValue(
-                        text_in=TextChunk(value["in"]),
+                        text_in=_maybe_parse_template(value["in"]),
                         value_out=value["out"],
                         context=value.get("context"),
                     )
@@ -251,3 +267,11 @@ def _parse_list(list_dict: Dict[str, Any]) -> SlotList:
         )
 
     raise ValueError(f"Unknown slot list type: {list_dict}")
+
+
+def _maybe_parse_template(text: str) -> Expression:
+    """Parse string as a sentence template if it has template syntax."""
+    if is_template(text):
+        return parse_sentence(text)
+
+    return TextChunk(normalize_text(text))
